! source file: /usr/local/models/UVic_ESCM/2.8/source/mom/cobc.h
!====================== include file "cobc.h" ==========================

      common /ccobc/ var
